Installation
============

Notes on how to install


##### PyPI
To install the core package run: `pip install glidertools`.
Check that you are using the correct version of `pip`.

##### GitHub
For the most up to date version of GliderTools, you can install directly from the online repository hosted on GitLab.

1. Clone glidertools to your local machine: `git clone https://github.com/luke-gregor/GliderTools`
2. Change to the parent directory of GliderTools
3. Install glidertools with `pip install -e ./GliderTools`. This will allow changes you make locally, to be reflected when you import the package in Python
